@@ -94,8 +94,8 @@ stud.ttests <- function(x, y = NULL, ina, logged = FALSE, parallel = FALSE) {
 
   m1 <- Rfast::colmeans(x1, parallel = parallel)
   m2 <- Rfast::colmeans(x2, parallel = parallel)
-  s1 <- Rfast::colVars(x1, suma = n1 * m1, parallel = parallel) 
-  s2 <- Rfast::colVars(x2, suma = n2 * m2, parallel = parallel)
+  s1 <- Rfast::colVars(x1, parallel = parallel) 
+  s2 <- Rfast::colVars(x2, parallel = parallel)
   sp <- ( (n1 - 1) * s1 + (n2 - 1) * s2 ) / (n1 + n2 - 2) 
   stat <- ( m1 - m2 ) / sqrt(sp * (1/n1 + 1/n2) )
   dof <- n1 + n2 - 2
