@@ -14,7 +14,7 @@ using namespace arma;
 #define rbind join_cols
 
 template<class Ret,class T>
-void combn(T vals, const int n, const unsigned int start_idx, 
+void combn(T vals, const int n, const unsigned int start_idx,
            std::vector<double>& combn_data, Ret& combn_ds, unsigned int& combn_col) {
     if (!n) {
         for (unsigned int i = 0; i < combn_ds.n_rows && combn_col < combn_ds.n_cols; i++) {
@@ -37,7 +37,7 @@ Ret find_combn(T vals, const int n) {
     Ret combn_ds(nrows, ncols);
     std::vector<double> combn_data(nrows);
     const unsigned int start_idx = 0;
-    combn_col = 0; 
+    combn_col = 0;
     combn<Ret,T>(vals, n, start_idx, combn_data, combn_ds, combn_col);
     return combn_ds;
 }
@@ -50,11 +50,11 @@ T pmax(T x,T y){
 }
 
 //[[Rcpp::export]]
-mat quasi_poisson_only(mat x, colvec y, const double ylogy, const double tol,const int maxiters){
+arma::mat quasi_poisson_only(arma::mat x, arma::colvec y, const double ylogy, const double tol,const int maxiters){
     const unsigned int n=x.n_rows,pcols=x.n_cols,d=2;
     unsigned int i;
     int ij;
-    
+
     colvec b_old(d),b_new(d),L1(d),yhat(n);
     mat z(n,2,fill::ones),inv_L2(d,d),ytr=y.t(),z_tr(2,n,fill::ones);
     vec m(n),z_col_1(n);
@@ -128,20 +128,20 @@ colvec poisson_only(mat x, colvec y,const double ylogy){
 colvec logistic_only(mat x, colvec y,const double d0,const double my,const double sy,const double lgmy,const double tol){
     int maxiters = 100;
     const unsigned int n=x.n_rows,pcols=x.n_cols;
-    
+
     unsigned int i=0;
     int j=0;
     colvec be(2),expyhat(n),W(n,fill::zeros),x_col(n),x2_col(n),de(n);
     mat yhat(n,1),p(n,1);
     colvec F(pcols);
     double d1=0,d2=0,t=0,dera2=0.0,sp=0.0,derb=0.0,dera=0.0,derab=0.0,derb2=0.0;
-    
+
     double W0=my*(1-my);
     double dera20=n*W0;
     colvec de0(n);
     de0=y-my;
     double dera0=0;
-    
+
     for(i=0;i<pcols;++i){
         d1=d0;
         be[0]=lgmy;
@@ -154,11 +154,11 @@ colvec logistic_only(mat x, colvec y,const double d0,const double my,const doubl
         t=dera20 * derb2 - derab*derab;
         be[0]=be[0]+(derb2 * dera0 - derab * derb)/t;
         be[1]=be[1]+( - derab * dera0 + dera20 * derb )/t;
-        
+
         yhat.col(0) = be[0]+be[1]*x_col;
         expyhat=exp(-yhat.col(0));
         p.col(0) = 1 / ( 1 + expyhat );
-        
+
         d2 = -2*calcDevRes(p,y,yhat);
         //errors("d1",d1);
         //errors("d2",d2);
@@ -179,10 +179,10 @@ colvec logistic_only(mat x, colvec y,const double d0,const double my,const doubl
             yhat.col(0) = be[0]+be[1]*x_col;
             expyhat=exp(-yhat.col(0));
             p.col(0) = 1 / ( 1 + expyhat );
-            
+
             d2 = -2*calcDevRes(p,y,yhat);
         }
-        
+
         F(i) = d2;
     }
     return F;
@@ -192,7 +192,7 @@ uvec std_setdiff(uvec& x,uvec b) {
     //panta x,y unique
     vector<unsigned int> out;
     std::set_difference(x.begin(), x.end(), b.begin(), b.end(),back_inserter(out));
-    
+
     return conv_to<uvec>::from(out);
 }
 
@@ -200,7 +200,7 @@ uvec std_setdiff(uvec& x,unsigned int y) {
     //panta x,y unique
     vector<unsigned int> out,b{y};
     std::set_difference(x.begin(), x.end(), b.begin(), b.end(),back_inserter(out));
-    
+
     return conv_to<uvec>::from(out);
 }
 
@@ -215,12 +215,12 @@ ucolvec find_arr_indices_c(umat x){
 }
 
 
-double calc_devi_0(vec y,mat x,add_term_ini_vars *ini,const int maxiters,const double tol,string test,const double lgmy=0.0,const double my=0.0,const double sy=0.0,const double d1=0.0,const double ylogy=0.0){
+double calc_devi_0(vec y,mat x,const add_term_ini_vars& ini,const int maxiters,const double tol,string test,const double lgmy=0.0,const double my=0.0,const double sy=0.0,const double d1=0.0,const double ylogy=0.0){
     double devi_0;
     if (test == "poisson" || test == "qpoisson") {  //## Poisson regression
         devi_0=2*ylogy+glm_poisson3(x, y,lgmy,tol,maxiters);
     } else if(test == "logistic") {
-        devi_0=glm_logistic3(x,y,&ini->my[0],ini->ini,tol,maxiters);
+        devi_0=glm_logistic3(x,y,&ini.my[0],ini.ini,tol,maxiters);
     }else{
         stop("Error: wrong type.\n");
     }
@@ -246,32 +246,32 @@ mat rep(unsigned int nrow,unsigned int ncol,unsigned int val){
 }
 
 List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string test = "logistic",SEXP Ini=R_NilValue,const bool parallel = false,const int maxiters = 100,const double tol = 1e-07,const bool backward = false) {
-    
+
     Timer timer;
-    
+
     timer.Start();
-    add_term_ini_vars* ini = add_term_ini(y, test, tol, maxiters);
+    add_term_ini_vars ini = add_term_ini(y, test, tol, maxiters);
     int sel,dm;
     umat cand;
     double devi_0,m;
     double my=0.0,sy=0.0,lgmy=0.0,d1=0.0,ylogy=0.0;
-    
+
     colvec pval,oness=ones(x.n_rows);
     const int varsize = x.n_cols;
-    
-    if ( max_k < 1L )   
+
+    if ( max_k < 1L )
         stop("invalid max_k option");
-    if ( max_k > varsize )   
+    if ( max_k > varsize )
         max_k = varsize;
-    if ( threshold <= 0 || threshold > 1 )   
+    if ( threshold <= 0 || threshold > 1 )
         stop("invalid threshold option");
-    
+
     unsigned int ntests = 0;
     List kapa_pval(max_k);
     double alpha = log(threshold);
-    
+
     if ( Rf_isNull(Ini) ) {
-        //errors("Enter null ini, 259\n");      
+        //errors("Enter null ini, 259\n");
         colvec stat,mod;
         const int n=x.n_rows;
         pval=colvec(varsize);
@@ -309,7 +309,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
             for(int i=0;i<varsize;++i)
                 pval[i] = R::pf(stat[i], 1, n - 2,0,1);
         }
-        
+
         ntests = varsize;
     } else {
         pval = as<colvec>(Ini);
@@ -320,7 +320,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
     uvec sela(1);
     if ( vars.n_elem > 0 ) {
         sela(0)=pval.index_min();
-    } else  
+    } else
         sela=vars;
     //errors(308);
     uvec ide;
@@ -357,7 +357,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
         }
         //errors("end 1 selected\n");
     }  //////## end  if ( vars.n_elem > 0  &  max_k >= 1 ) {
-    
+
     ////## 2 selected
     if ( vars.n_elem > 0  &&  max_k >= 1 ) {
         //errors("Enter 2 selected\n");
@@ -389,8 +389,8 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
         }
         //errors("end 2 selected\n");
     }  ////## end  if ( vars.n_elem > 0  &  max_k >= 1 ) {
-    
-    //## 3 selected  
+
+    //## 3 selected
     if ( vars.n_elem > 0  &&  max_k >= 1 ) {
         //errors("Enter 3 selected\n");
         if ( max_k >= 1 ) {
@@ -399,7 +399,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
             kapa_pval[0] = rbind( as<mat>(kapa_pval[0]), cbind(pval2,cbind(conv_to<mat>::from(vars), rep(vars.n_elem,1,sela(2)))+1));
             //errors(411);
             ntests+=vars.n_elem;
-            pval(vars)=pmax<colvec>(pval(vars),pval2); 
+            pval(vars)=pmax<colvec>(pval(vars),pval2);
             ide = find(pval(vars) < alpha);
             ide=find(pval(vars)<alpha);
             vars = vars(ide);
@@ -423,7 +423,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
             kapa_pval[1] = join_cols( as<mat>(kapa_pval[1]), join_rows( pval2, join_rows(conv_to<mat>::from(vars), (mat)repmat(conv_to<mat>::from(cand.col(2).t()), vars.n_elem,1))+1));
             //errors(436);
             ntests+=vars.n_elem;
-            pval(vars)=pmax<colvec>(pval(vars),pval2); 
+            pval(vars)=pmax<colvec>(pval(vars),pval2);
             ide = find(pval(vars) < alpha);
             ide=find(pval(vars)<alpha);
             vars = vars(ide);
@@ -435,11 +435,11 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
             //errors(447);
             kapa_pval[2] = join_rows( (mat)pval2, join_rows(conv_to<mat>::from(vars), (mat)repmat(conv_to<rowvec>::from(sela), vars.n_elem,1))+1);
             ntests+=vars.n_elem;
-            pval(vars)=pmax<colvec>(pval(vars),pval2); 
+            pval(vars)=pmax<colvec>(pval(vars),pval2);
             ide = find(pval(vars) < alpha);
             ide=find(pval(vars)<alpha);
             vars = vars(ide);
-        } 
+        }
         //## end  if ( max_k >= 3 ) {
         if( vars.n_elem > 0){
             sel=pval(vars).index_min();
@@ -447,8 +447,8 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
             vars = std_setdiff(vars, vars(sel));
         }
         //errors("end 3 selected\n");
-    }  //## end  if ( vars.n_elem > 0  &  max_k >= 2 ) {  
-    
+    }  //## end  if ( vars.n_elem > 0  &  max_k >= 2 ) {
+
     //## 4 selected
     while ( vars.n_elem > 0  &&  max_k >= 1 ) {
         dm = sela.n_elem-1;
@@ -457,12 +457,12 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
         //errors(468);
         kapa_pval[0] = join_cols( as<mat>(kapa_pval[0]), join_rows(pval2, join_rows(conv_to<mat>::from(vars), rep(vars.n_elem,1,sela(dm)))+1));
         ntests+=vars.n_elem;
-        pval(vars)=pmax<colvec>(pval(vars),pval2); 
+        pval(vars)=pmax<colvec>(pval(vars),pval2);
         ide = find(pval(vars) < alpha);
         vars = vars(ide);
         if ( vars.n_elem > 0  &&  max_k >= 2 ) {
             uvec sort_sela=sort(sela);
-            for (int i=1;i<max_k;++i) {   //  Mixail comment:  change into this -> for ( i in 2:min( max_k, length(sela) ) ) {   
+            for (int i=1;i<max_k;++i) {   //  Mixail comment:  change into this -> for ( i in 2:min( max_k, length(sela) ) ) {
                 cand = find_combn<umat,uvec>(sort_sela, i+1); // anagkastika i+1 gia na vgalei 2 arithmous
                 cand = cand.cols(find_arr_indices_c(cand==sela(dm)));  // Michail comment: delete this row
                 for(int j=0;vars.n_elem > 0  &&  j < (int)cand.n_cols;++j){
@@ -475,11 +475,11 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
                     //errors("row,col = ",tmp1.n_rows,".",tmp1.n_cols);
                     kapa_pval[i] = join_cols( as<mat>(kapa_pval[i]), join_rows( pval2, join_rows(conv_to<mat>::from(vars), (mat)repmat(conv_to<rowvec>::from(cand.col(j)), vars.n_elem,1))+1));
                     ntests+=vars.n_elem;
-                    pval(vars)=pmax<colvec>(pval(vars),pval2); 
+                    pval(vars)=pmax<colvec>(pval(vars),pval2);
                     ide = find(pval(vars) < alpha);
                     vars = vars(ide);
                 }  //## end  for ( j in 1:dim(cand)[2] ) {
-            }  //## end  for ( i in 2:max_k ) {  
+            }  //## end  for ( i in 2:max_k ) {
         }  //## end  if ( max_k >= 2 ) {
         //errors("iiiiiiiiiiiiiiiiiii: ",vars.n_elem);
         colvec pval_vars=pval(vars);
@@ -490,7 +490,7 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
         }
         //errors(505);
     } //## end  while ( vars.n_elem > 0  &  max_k >= 1 ) {
-    
+
     /*if ( backward  && sela.n_elem > 0  ) {
     pv = pval(sela);
     sela = sela( order(pv) );
@@ -502,12 +502,12 @@ List mmpc2(vec y,mat x,int max_k = 3,const double threshold = 0.05,const string
     runtime = runtime + proc.time() - tic
 } */
     timer.Stop();
-    return List::create(_["selectedVars"] = sela+1, _["pvalues"] = pval, _["univ"] = univ, 
+    return List::create(_["selectedVars"] = sela+1, _["pvalues"] = pval, _["univ"] = univ,
                         _["kapa_pval"] = kapa_pval, _["max_k"] = max_k, _["threshold"] = alpha,
                         _["n.tests"] = ntests,_["runtime"]=timer.getTime());
 }
 
-    
+
 RcppExport SEXP Rfast2_mmpc2(SEXP ySEXP,SEXP xSEXP,SEXP max_kSEXP,SEXP thresholdSEXP,SEXP testSEXP,SEXP Ini,SEXP parallelSEXP,SEXP maxitersSEXP,SEXP tolSEXP,SEXP backwardSEXP){
 BEGIN_RCPP
     RObject __result;
